mix cauldron.report (Cauldron2D v0.1.3)

Copy Markdown View Source

Summarise a trace written by Cauldron2D.Trace.

CAULDRON_TRACE=1 mix my_game        # play, then quit
mix cauldron.report                 # reads ./cauldron_trace.log
mix cauldron.report /tmp/run.log --from mouse --to paddle_start

Prints how many events of each kind there were and, for each kind, the median, p90 and longest gap between one and the next in milliseconds. With --from and --to, also the time from each from event to the next to event: how long the game took to answer.